@@ -1,12 +1,12 @@
 from .forecast_flows_handling import post_flows_to_database
-from .forecast_flows_handling import get_index_review_data_from_db
 from .forecast_flows_handling import get_all_index_data_from_db
-from .forecast_flows_handling import get_index_review_data_daterange
+from .forecast_flows_handling import get_index_review_data_from_db
 from .forecast_flows_handling import get_index_review_data_single_day
+from .forecast_flows_handling import get_index_review_data_daterange
 
 from .date_handling import post_dates_to_database
-from .date_handling import get_index_dates_data_from_db
 from .date_handling import get_all_index_dates_from_db
+from .date_handling import get_index_dates_data_from_db
 
 from .user_handling import create_user
 from .user_handling import login_user
@@ -14,5 +14,8 @@ from .user_handling import get_user_identification
 
 from .announcement_handling import post_announcements_to_database
 from .announcement_handling import get_all_index_announcements_from_db
-from .announcement_handling import get_index_announcement_data_from_db
 from .announcement_handling import get_multiple_index_announcement_data_from_db
+from .announcement_handling import get_index_announcement_data_from_db
+
+from .name_handling import post_index_name_acronyms_to_database
+from .name_handling import get_index_name_acronyms_from_database
